@@ -1,7 +1,13 @@
 #ifndef DIALOGS_QT_UTILITIES_QTSETTINGS_H
 #define DIALOGS_QT_UTILITIES_QTSETTINGS_H
 
+#include "../global.h"
+
+#if defined(QT_UTILITIES_GUI_QTWIDGETS)
 #include "./optionpage.h"
+#endif
+
+#include <QtGlobal>
 
 #include <memory>
 
@@ -13,6 +19,7 @@ namespace QtUtilities {
 class OptionCategory;
 struct QtSettingsData;
 
+#if defined(QT_UTILITIES_GUI_QTWIDGETS)
 BEGIN_DECLARE_UI_FILE_BASED_OPTION_PAGE_CUSTOM_CTOR(QtAppearanceOptionPage)
 public:
 explicit QtAppearanceOptionPage(QtSettingsData &settings, QWidget *parentWidget = nullptr);
@@ -40,17 +47,21 @@ private:
 DECLARE_SETUP_WIDGETS
 QtSettingsData & m_settings;
 END_DECLARE_OPTION_PAGE
+#endif
 
 class QT_UTILITIES_EXPORT QtSettings {
 public:
     QtSettings();
     ~QtSettings();
 
+#if defined(QT_UTILITIES_GUI_QTWIDGETS)
     void disableNotices();
     void setRetranslatable(bool retranslatable);
+#endif
     void restore(QSettings &settings);
     void save(QSettings &settings) const;
     void apply();
+    void reapplyDefaultIconTheme(bool isPaletteDark);
     void reevaluatePaletteAndDefaultIconTheme();
     bool isPaletteDark();
     bool hasCustomFont() const;
@@ -64,8 +75,10 @@ private:
 };
 } // namespace QtUtilities
 
+#if defined(QT_UTILITIES_GUI_QTWIDGETS)
 DECLARE_EXTERN_UI_FILE_BASED_OPTION_PAGE(QtAppearanceOptionPage)
 DECLARE_EXTERN_UI_FILE_BASED_OPTION_PAGE(QtLanguageOptionPage)
 DECLARE_EXTERN_UI_FILE_BASED_OPTION_PAGE(QtEnvOptionPage)
+#endif
 
 #endif // DIALOGS_QT_UTILITIES_QTSETTINGS_H
